@@ -1,5 +1,7 @@
 context("fcumsum")
 
+if(!is.null(attributes(identical(FALSE, TRUE)))) stop("OECD label issue")
+
 # rm(liso = ls())
 set.seed(101)
 x <- abs(1000*rnorm(100))
@@ -41,6 +43,8 @@ od = order(od)
 
 bcumsum <- base::cumsum
 
+if(requireNamespace("data.table", quietly = TRUE)) {
+
 basecumsum <- function(x, na.rm = TRUE, fill = FALSE) {
   ax <- attributes(x)
   if(!na.rm || !anyNA(x)) return(`attributes<-`(bcumsum(x), ax))
@@ -95,6 +99,8 @@ test_that("fcumsum performs like basecumsum", {
   expect_equal(fcumsum(num_vars(dataNA), g, fill = TRUE), BY(num_vars(dataNA), g, basecumsum, fill = TRUE, use.g.names = FALSE))
 })
 
+}
+
 test_that("fcumsum correctly handles unordered time-series and panel-series computations", {
   # With ordering, no groups: 1
   expect_equal(fcumsum(x, o = 1:100), fcumsum(x))
@@ -209,6 +215,8 @@ storage.mode(mNAuo) <- "integer"
 settransformv(datauo, is.numeric, as.integer)
 settransformv(dataNAuo, is.numeric, as.integer)
 
+if(requireNamespace("data.table", quietly = TRUE)) {
+
 test_that("fcumsum with integers performs like basecumsum", {
   # No groups, no ordering
   expect_identical(fcumsum(x), basecumsum(x))
@@ -250,6 +258,8 @@ test_that("fcumsum with integers performs like basecumsum", {
   expect_identical(fcumsum(num_vars(dataNA), g, fill = TRUE), BY(num_vars(dataNA), g, basecumsum, fill = TRUE, use.g.names = FALSE))
 })
 
+}
+
 test_that("fcumsum with integers correctly handles unordered time-series and panel-series computations", {
   # With ordering, no groups: 1
   expect_identical(fcumsum(x, o = 1:100), fcumsum(x))
